Project Info
===============================================================================

=============== ===============================================================
Category        Hyperlink
=============== ===============================================================
Documentation:  http://pythonhosted.org/behave/
                (or: https://behave.readthedocs.org/)
Download:       http://pypi.python.org/pypi/behave (or: `github archive`_)
Development:    https://github.com/behave/behave
Issue Tracker:  https://github.com/behave/behave/issues
Changelog:      `CHANGES.rst <CHANGES.rst>`_
=============== ===============================================================

.. hint::

    The PyPI version is the latest stable version.
    Otherwise, use the latest stable tag or the "bleeding edge" from Github.

.. _`github archive`: https://github.com/behave/behave/tags
